summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoPageLayoutDia.h')
-rw-r--r--lib/kofficeui/KoPageLayoutDia.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kofficeui/KoPageLayoutDia.h b/lib/kofficeui/KoPageLayoutDia.h
index 05f8f3db..21fe7df3 100644
--- a/lib/kofficeui/KoPageLayoutDia.h
+++ b/lib/kofficeui/KoPageLayoutDia.h
@@ -90,7 +90,7 @@ public:
/**
* Constructor.
*
* @param tqparent The tqparent of the dialog.
* @param name The name of the dialog.
* @param tqlayout The tqlayout.
* @param headfoot The header and the footer.
@@ -98,7 +98,7 @@ public:
* @param unit The unit to use for displaying the values to the user.
* @param modal Whether the dialog is modal or not.
*/
- KoPageLayoutDia( TQWidget* tqparent, const char* name,
+ KoPageLayoutDia( TQWidget* parent, const char* name,
const KoPageLayout& tqlayout,
const KoHeadFoot& headfoot,
int flags, KoUnit::Unit unit, bool modal=true );
@@ -106,7 +106,7 @@ public:
/**
* Constructor.
*
* @param tqparent The tqparent of the dialog.
* @param name The name of the dialog.
* @param tqlayout The tqlayout.
* @param headfoot The header and the footer.
@@ -115,7 +115,7 @@ public:
* @param tabs The number of tabs.
* @param unit The unit to use for displaying the values to the user
*/
- KoPageLayoutDia( TQWidget* tqparent, const char* name,
+ KoPageLayoutDia( TQWidget* parent, const char* name,
const KoPageLayout& tqlayout,
const KoHeadFoot& headfoot,
const KoColumns& columns,
@@ -131,13 +131,13 @@ public:
* Show page tqlayout dialog.
* See constructor for documentation on the parameters
*/
- static bool pageLayout( KoPageLayout&, KoHeadFoot&, int tabs, KoUnit::Unit& unit, TQWidget* tqparent = 0 );
+ static bool pageLayout( KoPageLayout&, KoHeadFoot&, int tabs, KoUnit::Unit& unit, TQWidget* parent = 0 );
/**
* Show page tqlayout dialog.
* See constructor for documentation on the parameters
*/
- static bool pageLayout( KoPageLayout&, KoHeadFoot&, KoColumns&, KoKWHeaderFooter&, int tabs, KoUnit::Unit& unit, TQWidget* tqparent = 0 );
+ static bool pageLayout( KoPageLayout&, KoHeadFoot&, KoColumns&, KoKWHeaderFooter&, int tabs, KoUnit::Unit& unit, TQWidget* parent = 0 );
/**
* Retrieves a standard page tqlayout.
* Deprecated: better use KoPageLayout::standardLayout()
@@ -90,7 +90,7 @@ public:
* Constructor.
*
- * @param tqparent The tqparent of the dialog.
+ * @param parent The parent of the dialog.
* @param name The name of the dialog.
* @param tqlayout The tqlayout.
@@ -106,7 +106,7 @@ public:
* Constructor.
*
- * @param tqparent The tqparent of the dialog.
+ * @param parent The parent of the dialog.
* @param name The name of the dialog.
* @param tqlayout The tqlayout.